/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

This file is part of Scotty.

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/
package cmd

import (
	"github.com/spf13/cobra"
	"github.com/spf13/viper"
	"go.uploadedlobster.com/scotty/internal/backends"
	"go.uploadedlobster.com/scotty/internal/cli"
	"go.uploadedlobster.com/scotty/internal/models"
	"go.uploadedlobster.com/scotty/internal/storage"
)

// listensCmd represents the listens command
var listensCmd = &cobra.Command{
	Use:   "listens",
	Short: "Transfer listens between two services",
	Long:  `Transfers listens between two configured services.`,
	Run: func(cmd *cobra.Command, args []string) {
		db, err := storage.New(viper.GetString("database"))
		cobra.CheckErr(err)
		c, err := cli.NewTransferCmd[
			models.ListensExport,
			models.ListensImport,
			models.ListensResult,
		](cmd, &db, "listens")
		cobra.CheckErr(err)
		exp := backends.ListensExportProcessor{Backend: c.ExpBackend}
		imp := backends.ListensImportProcessor{Backend: c.ImpBackend}
		err = c.Transfer(exp, imp)
		cobra.CheckErr(err)
	},
}

func init() {
	beamCmd.AddCommand(listensCmd)
	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// listensCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	// listensCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
}
