/*
Copyright © 2023 Philipp Wolfer <phw@uploadedlobster.com>

Scotty is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later version.

Scotty is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
Scotty. If not, see <https://www.gnu.org/licenses/>.
*/

package cli

import (
	"fmt"

	"github.com/spf13/cobra"
	"github.com/spf13/viper"
)

func GetConfigFromFlag(cmd *cobra.Command, flagName string) (string, *viper.Viper) {
	configName := cmd.Flag(flagName).Value.String()
	var config *viper.Viper
	servicesConfig := viper.Sub("service")
	if servicesConfig != nil {
		config = servicesConfig.Sub(configName)
	}
	if config == nil {
		cobra.CheckErr(fmt.Sprintf("Invalid source configuration \"%s\"", configName))
	}
	return configName, config
}

func getInt64FromFlag(cmd *cobra.Command, flagName string) (result int64) {
	result, err := cmd.Flags().GetInt64(flagName)
	if err != nil {
		result = 0
	}
	return
}
